### Name: condmap
### Title: Produces a conditional 2D map from a fitted max-stable process
### Aliases: condmap
### Keywords: hplot

### ** Examples

## Not run: 
##D require(RandomFields)
##D 
##D ##Define the coordinate of each location
##D n.site <- 30
##D locations <- matrix(runif(2*n.site, 0, 10), ncol = 2)
##D colnames(locations) <- c("lon", "lat")
##D 
##D sigma <- matrix(c(4, 1, 1, 3), 2)
##D sigma.inv <- solve(sigma)
##D sqrtCinv <- t(chol(sigma.inv))
##D model <- list(list(model = "gauss", var = 1, aniso = sqrtCinv / 2))
##D 
##D ##Simulate a max-stable process - with unit Frechet margins
##D ms0 <- MaxStableRF(locations[,1], locations[,2], grid=FALSE,
##D                    model = model, maxstable = "Bool", n = 40)
##D ms0 <- t(ms0)
##D ms1 <- ms0
##D 
##D ##Now define the spatial model for the GEV parameters
##D param.loc <- -10 - 4 * locations[,1] + locations[,2]^2
##D param.scale <- 5 + locations[,1] + locations[,2]^2 / 10
##D param.shape <- rep(.2, n.site)
##D 
##D ##Transform the unit Frechet margins to GEV 
##D for (i in 1:n.site)
##D   ms1[,i] <- param.scale[i] * (ms1[,i]^param.shape[i] - 1) /
##D   param.shape[i] + param.loc[i]
##D 
##D ##Define a model for the GEV margins to be fitted
##D ##shape ~ 1 stands for the GEV shape parameter is constant
##D ##over the region
##D loc.form <- loc ~ lon + I(lat^2)
##D scale.form <- scale ~ lon + I(lat^2)
##D shape.form <- shape ~ lat + lon
##D 
##D ##  1- Fit a max-stable process
##D fitted <- fitmaxstab(ms1, locations, "gauss", loc.form, scale.form,
##D                      shape.form, std.err.type = "none")
##D 
##D condmap(fitted, c(1, 1), seq(0, 10, length = 25), seq(0,10, length =
##D 25))
## End(Not run)



