### Name: covariance
### Title: Defines and computes covariance functions
### Aliases: covariance
### Keywords: htest

### ** Examples

## 1- Calling covariance using fixed covariance parameters
covariance(sill = 1, range = 1, smooth = 0.5, cov.mod = "whitmat")
covariance(sill = 0.5, range = 1, smooth = 0.5, cov.mod = "whitmat",
  dist = seq(0,5, 0.2), plot = FALSE)

## 2- Calling covariance from a fitted model
## Not run: 
##D require(RandomFields)
##D 
##D ##Define the coordinate of each location
##D n.site <- 30
##D locations <- matrix(runif(2*n.site, 0, 10), ncol = 2)
##D colnames(locations) <- c("lon", "lat")
##D 
##D ##Simulate a max-stable process - with unit Frechet margins
##D ms0 <- MaxStableRF(locations[,1], locations[,2], grid=FALSE, model="wh",
##D                    param=c(0,1,0,3, .5), maxstable="extr",
##D                    n = 30)
##D ms1 <- t(ms0)
##D 
##D ##Now define the spatial model for the GEV parameters
##D param.loc <- -10 + 2 * locations[,2]
##D param.scale <- 5 + 2 * locations[,1] + locations[,2]^2
##D param.shape <- rep(0.2, n.site)
##D ##Transform the unit Frechet margins to GEV 
##D for (i in 1:n.site)
##D   ms1[,i] <- param.scale[i] * (ms1[,i]^param.shape[i] - 1) /
##D   param.shape[i] + param.loc[i]
##D 
##D ##Define a model for the GEV margins to be fitted
##D ##shape ~ 1 stands for a constant GEV shape parameter
##D ##over the region
##D loc.form <- loc ~ lat
##D scale.form <- scale ~ lon + I(lat^2)
##D shape.form <- shape ~ 1
##D 
##D fitted <- fitmaxstab(ms1, locations, "whitmat", loc.form, scale.form,
##D                shape.form)
##D covariance(fitted, ylim = c(0, 1))
##D covariance(sill = 1, range = 3, smooth = .5, cov.mod = "whitmat", add = TRUE, col
##D                = 3)
##D title("Whittle-Matern covariance function")
##D legend("topright", c("Theo.", "Fitted"), lty = 1, col = c(3,1), inset =
##D            .05)
## End(Not run)



