### Name: map
### Title: Produces a 2D map from a fitted max-stable process
### Aliases: map
### Keywords: hplot

### ** Examples

## Not run: 
##D require(RandomFields)
##D 
##D ##Define the coordinate of each location
##D n.site <- 30
##D locations <- matrix(runif(2*n.site, 0, 10), ncol = 2)
##D colnames(locations) <- c("lon", "lat")
##D 
##D ##Simulate a max-stable process - with unit Frechet margins
##D ms0 <- MaxStableRF(locations[,1], locations[,2], grid=FALSE, model="wh",
##D                    param=c(0,1,0,30, .5), maxstable="extr",
##D                    n = 40)
##D ms0 <- t(ms0)
##D ms1 <- ms0
##D 
##D ##Now define the spatial model for the GEV parameters
##D param.loc <- -10 - 4 * locations[,1] + locations[,2]^2
##D param.scale <- 5 + locations[,1] + locations[,2]^2 / 10
##D param.shape <- rep(.2, n.site)
##D 
##D ##Transform the unit Frechet margins to GEV 
##D for (i in 1:n.site)
##D   ms1[,i] <- param.scale[i] * (ms1[,i]^param.shape[i] - 1) /
##D   param.shape[i] + param.loc[i]
##D 
##D ##Define a model for the GEV margins to be fitted
##D ##shape ~ 1 stands for the GEV shape parameter is constant
##D ##over the region
##D loc.form <- loc ~ lon + I(lat^2)
##D scale.form <- scale ~ lon + I(lat^2)
##D shape.form <- shape ~ lat + lon
##D 
##D ##  1- Fit a max-stable process
##D schlather <- fitmaxstab(ms1, locations, "whitmat", loc.form, scale.form,
##D                         shape.form)
##D 
##D ##  2- Produce a map of the location, scale and shape parameters
##D map(schlather, "loc", col = rainbow(80))
##D title("Location")
##D map(schlather, "scale", col = heat.colors(80))
##D title("Scale")
##D map(schlather, "shape", col = topo.colors(100))
##D title("Shape")
##D ##  3- Produce a map for the 50 years return level
##D new.ranges <- cbind(c(0, 15), c(0, 15))
##D colnames(new.ranges) <- c("lon", "lat")
##D 
##D map(schlather, "quant", ret.per = 50 , ranges = new.ranges)
##D title("50-year return level")
## End(Not run)



