### Name: profile
### Title: Method for profiling fitted max-stable objects
### Aliases: profile profile.maxstab
### Keywords: models

### ** Examples

require(RandomFields)

##Define the coordinates of each location
n.site <- 30
locations <- matrix(rnorm(2*n.site, sd = sqrt(.2)), ncol = 2)
colnames(locations) <- c("lon", "lat")

##Simulate a max-stable process - with unit Frechet margins
sigma <- matrix(c(100, 25, 25, 220),ncol = 2)
sigma.inv <- solve(sigma)
sqrtCinv <- t(chol(sigma.inv))
model <- list(list(model = "gauss", var = 1, aniso = sqrtCinv / 2))
ms0 <- MaxStableRF(locations[,1], locations[,2], grid=FALSE, model=model,
                   maxstable="Bool", n = 50)
ms0 <- t(ms0)
##Fit a max-stable process
##  1- using the Smith's model
## Not run: 
##D fitted <- fitmaxstab(ms0, locations, "gauss", fit.marge = FALSE)
## End(Not run)

##Plot the profile pairwise log-likelihood for the ''cov11'' parameter
## Not run: profile(fitted, "cov11", range = c(20, 180))



