### Name: profile2d
### Title: Method for profiling (in 2d) fitted max-stable objects
### Aliases: profile2d profile2d.maxstab
### Keywords: models

### ** Examples

require(RandomFields)

##Define the coordinates of each location
n.site <- 30
locations <- matrix(rnorm(2*n.site, sd = sqrt(.2)), ncol = 2)
colnames(locations) <- c("lon", "lat")

##Simulate a max-stable process - with unit Frechet margins
ms0 <- MaxStableRF(locations[,1], locations[,2], grid=FALSE, model="wh",
                   param=c(0,1,0,30, .5), maxstable="extr",
                   n = 30)
ms1 <- t(ms0)

##Now define the spatial model for the GEV parameters
param.loc <- -10 + 2 * locations[,2]
param.scale <- 5 + 2 * locations[,1] + locations[,2]^2
param.shape <- rep(0.2, n.site)
##Transform the unit Frechet margins to GEV 
for (i in 1:n.site)
  ms1[,i] <- param.scale[i] * (ms1[,i]^param.shape[i] - 1) /
  param.shape[i] + param.loc[i]

##Define a model for the GEV margins to be fitted
##shape ~ 1 stands for the GEV shape parameter is constant
##over the region
loc.form <- loc ~ lat
scale.form <- scale ~ lon + (lat^2)
shape.form <- shape ~ 1

##Fit a max-stable process
##  1- using the Schlather representation
## Not run: 
##D fitted <- fitmaxstab(ms1, locations, "schlather", loc.form, scale.form,
##D                      shape.form)
## End(Not run)

##Plot the profile pairwise log-likelihood for the smooth parameter
## Not run: 
##D ranges <- rbind(c(9,11), c(.3, .8))
##D profile2d(fitted, c("range", "smooth"), ranges = ranges)
## End(Not run)



