###################################################
### chunk number 1: 
###################################################
library(SpatialExtremes)
##image(volcano, col = terrain.colors(100), xaxt = "n", yaxt="n")
##contour(volcano, add = TRUE)
set.seed(12)
n.site <- 50
locations <- matrix(runif(2*n.site, 0, 10), ncol = 2)
colnames(locations) <- c("lon", "lat")

##Simulate a max-stable process - with unit Frechet margins
ms0 <- MaxStableRF(locations[,1], locations[,2], grid=FALSE, model="wh",
                   param=c(0,1,0,1, 2), maxstable="extr",
                   n = 40)
ms0 <- t(ms0)

##Compute the lambda-madogram
lmadogram(ms0, locations, n.bins = 25, border = "grey", box = FALSE)


###################################################
### chunk number 2: 
###################################################
options(SweaveHooks=list(fig=function()
par(mar=c(5.1, 4.1, 1.1, 2.1))))


###################################################
### chunk number 3:  eval=FALSE
###################################################
## vignette("SpatialExtremesGuide")


###################################################
### chunk number 4: Smith2Sim
###################################################
x <- y <- seq(0, 10, length = 100)
sigma <- matrix(c(9/8, 0, 0, 9/8),ncol = 2)
sigma2 <- matrix(c(9/8, 1, 1, 9/8),ncol = 2)
sigma.inv <- solve(sigma)
sqrtCinv <- t(chol(sigma.inv))
sigma.inv2 <- solve(sigma2)
sqrtCinv2 <- t(chol(sigma.inv2))
model <- list(list(model = "gauss", var = 1, aniso = sqrtCinv / 2))
model2 <- list(list(model = "gauss", var = 1, aniso = sqrtCinv2 / 2))
set.seed(12)
ms0 <- MaxStableRF(x, y, grid=TRUE, model = model, maxstable = "Bool")
ms0 <- t(ms0)
set.seed(12)
ms1 <- MaxStableRF(x, y, grid=TRUE, model = model2, maxstable = "Bool")
ms1 <- t(ms1)

par(mfrow=c(1,2))
image(x, y, ms0, col = terrain.colors(30))
image(x, y, ms1, col = terrain.colors(30))


###################################################
### chunk number 5: 
###################################################
x <- y <- seq(0, 10, length = 100)
sigma <- matrix(c(9/8, 0, 0, 9/8),ncol = 2)
sigma2 <- matrix(c(9/8, 1, 1, 9/8),ncol = 2)
sigma.inv <- solve(sigma)
sqrtCinv <- t(chol(sigma.inv))
sigma.inv2 <- solve(sigma2)
sqrtCinv2 <- t(chol(sigma.inv2))
model <- list(list(model = "gauss", var = 1, aniso = sqrtCinv / 2))
model2 <- list(list(model = "gauss", var = 1, aniso = sqrtCinv2 / 2))
set.seed(12)
ms0 <- MaxStableRF(x, y, grid=TRUE, model = model, maxstable = "Bool")
ms0 <- t(ms0)
set.seed(12)
ms1 <- MaxStableRF(x, y, grid=TRUE, model = model2, maxstable = "Bool")
ms1 <- t(ms1)

par(mfrow=c(1,2))
image(x, y, ms0, col = terrain.colors(30))
image(x, y, ms1, col = terrain.colors(30))


###################################################
### chunk number 6: covariances
###################################################
par(mfrow=c(1,3))
covariance(sill = 1, range = 1, smooth = 4, cov.mod = "whitmat",
           xlim = c(0,6), ylim = c(0, 1))
covariance(sill = 1, range = 1, smooth = 2, cov.mod = "whitmat",
           add = TRUE, col = 2, xlim = c(0,6))
covariance(sill = 1, range = 1, smooth = 1, cov.mod = "whitmat",
           add = TRUE, col = 3, xlim = c(0,6))
covariance(sill = 1, range = 1, smooth = 0.5, cov.mod = "whitmat",
           col = 4, add = TRUE, xlim = c(0,6))
legend("topright", c(expression(nu == 4), expression(nu == 2),
                     expression(nu == 1), expression(nu == 0.5)),
       col = 1:4, lty = 1, inset = 0.05)

covariance(sill = 1, range = 1, smooth = 2, cov.mod = "powexp",
           xlim = c(0, 3), ylim = c(0, 1))
covariance(sill = 1, range = 1, smooth = 1.5, cov.mod = "powexp",
           add = TRUE, col = 2, xlim = c(0, 3))
covariance(sill = 1, range = 1, smooth = 1, cov.mod = "powexp",
           add = TRUE, col = 3, xlim = c(0, 3))
covariance(sill = 1, range = 1, smooth = 0.75, cov.mod = "powexp",
           add = TRUE, col = 4, xlim = c(0, 3))
legend("topright", c(expression(nu == 2), expression(nu == 1.5),
                     expression(nu == 1), expression(nu == 0.75)),
       col = 1:4, lty = 1, inset = 0.05)

covariance(sill = 1, range = 1, smooth = 4, cov.mod = "cauchy",
           xlim = c(0, 3), ylim = c(0, 1))
covariance(sill = 1, range = 1, smooth = 2, cov.mod = "cauchy",
           add = TRUE, col = 2, xlim = c(0, 3))
covariance(sill = 1, range = 1, smooth = 1, cov.mod = "cauchy",
           add = TRUE, col = 3, xlim = c(0, 3))
covariance(sill = 1, range = 1, smooth = 0.75, cov.mod = "cauchy",
           add = TRUE, col = 4, xlim = c(0, 3))
legend("topright", c(expression(nu == 4), expression(nu == 2),
                     expression(nu == 1), expression(nu == 0.75)),
       col = 1:4, lty = 1, inset = 0.05)


###################################################
### chunk number 7: 
###################################################
par(mfrow=c(1,3))
covariance(sill = 1, range = 1, smooth = 4, cov.mod = "whitmat",
           xlim = c(0,6), ylim = c(0, 1))
covariance(sill = 1, range = 1, smooth = 2, cov.mod = "whitmat",
           add = TRUE, col = 2, xlim = c(0,6))
covariance(sill = 1, range = 1, smooth = 1, cov.mod = "whitmat",
           add = TRUE, col = 3, xlim = c(0,6))
covariance(sill = 1, range = 1, smooth = 0.5, cov.mod = "whitmat",
           col = 4, add = TRUE, xlim = c(0,6))
legend("topright", c(expression(nu == 4), expression(nu == 2),
                     expression(nu == 1), expression(nu == 0.5)),
       col = 1:4, lty = 1, inset = 0.05)

covariance(sill = 1, range = 1, smooth = 2, cov.mod = "powexp",
           xlim = c(0, 3), ylim = c(0, 1))
covariance(sill = 1, range = 1, smooth = 1.5, cov.mod = "powexp",
           add = TRUE, col = 2, xlim = c(0, 3))
covariance(sill = 1, range = 1, smooth = 1, cov.mod = "powexp",
           add = TRUE, col = 3, xlim = c(0, 3))
covariance(sill = 1, range = 1, smooth = 0.75, cov.mod = "powexp",
           add = TRUE, col = 4, xlim = c(0, 3))
legend("topright", c(expression(nu == 2), expression(nu == 1.5),
                     expression(nu == 1), expression(nu == 0.75)),
       col = 1:4, lty = 1, inset = 0.05)

covariance(sill = 1, range = 1, smooth = 4, cov.mod = "cauchy",
           xlim = c(0, 3), ylim = c(0, 1))
covariance(sill = 1, range = 1, smooth = 2, cov.mod = "cauchy",
           add = TRUE, col = 2, xlim = c(0, 3))
covariance(sill = 1, range = 1, smooth = 1, cov.mod = "cauchy",
           add = TRUE, col = 3, xlim = c(0, 3))
covariance(sill = 1, range = 1, smooth = 0.75, cov.mod = "cauchy",
           add = TRUE, col = 4, xlim = c(0, 3))
legend("topright", c(expression(nu == 4), expression(nu == 2),
                     expression(nu == 1), expression(nu == 0.75)),
       col = 1:4, lty = 1, inset = 0.05)


###################################################
### chunk number 8:  eval=FALSE
###################################################
## covariance(sill = 1, range = 1, smooth = 4, cov.mod = "whitmat",
##            xlim = c(0,6), ylim = c(0, 1))
## covariance(sill = 1, range = 1, smooth = 2, cov.mod = "whitmat",
##            add = TRUE, col = 2, xlim = c(0,6))
## covariance(sill = 1, range = 1, smooth = 1, cov.mod = "whitmat",
##            add = TRUE, col = 3, xlim = c(0,6))
## covariance(sill = 1, range = 1, smooth = 0.5, cov.mod = "whitmat",
##            col = 4, add = TRUE, xlim = c(0,6))
## legend("topright", c(expression(nu == 4), expression(nu == 2),
##                      expression(nu == 1), expression(nu == 0.5)),
##        col = 1:4, lty = 1, inset = 0.05)


###################################################
### chunk number 9: Schlather2Sim
###################################################
x <- y <- seq(0, 10, length = 100)
set.seed(12)
ms0 <- MaxStableRF(x, y, grid=TRUE, model="wh", param=c(0,1,0,1, 1), maxstable="extr")
ms0 <- t(ms0)
set.seed(12)
ms1 <- MaxStableRF(x, y, grid=TRUE, model="stable", param=c(0,1,0,1.5, 1), maxstable="extr")
ms1 <- t(ms1)

par(mfrow=c(1,2))
image(x, y, ms0, col = terrain.colors(30))
image(x, y, ms1, col = terrain.colors(30))


###################################################
### chunk number 10: 
###################################################
x <- y <- seq(0, 10, length = 100)
set.seed(12)
ms0 <- MaxStableRF(x, y, grid=TRUE, model="wh", param=c(0,1,0,1, 1), maxstable="extr")
ms0 <- t(ms0)
set.seed(12)
ms1 <- MaxStableRF(x, y, grid=TRUE, model="stable", param=c(0,1,0,1.5, 1), maxstable="extr")
ms1 <- t(ms1)

par(mfrow=c(1,2))
image(x, y, ms0, col = terrain.colors(30))
image(x, y, ms1, col = terrain.colors(30))


###################################################
### chunk number 11: anisoCovFun
###################################################
cov.fun <- covariance(sill = 1, range = 1, smooth = 1,
                      cov.mod = "powexp", plot = FALSE)
phi <- pi / 4
r <- sqrt(0.5)
A <- matrix(c(cos(phi), r^2 * sin(phi), r^2 * sin(phi), cos(phi)), 2)
cov.fun.aniso <- function(vec.pos)
  cov.fun(sqrt(vec.pos %*% A %*% vec.pos))

rho1 <- rho2 <- matrix(NA, 100, 100)
xs <- ys <- seq(-4, 4, length = 100)
for (i in 1:100){
  x <- xs[i]
  for (j in 1:100){
    rho1[i,j] <- cov.fun(sqrt(x^2+ys[j]^2))
    rho2[i,j] <- cov.fun.aniso(c(x, ys[j]))
  }
}

par(mfrow=c(1,2))
contour(xs, ys, rho1, xlab = expression(paste(Delta, x)),
        ylab = expression(paste(Delta, y)))
contour(xs, ys, rho2, xlab = expression(paste(Delta, x)),
        ylab = expression(paste(Delta, y)))


###################################################
### chunk number 12: 
###################################################
cov.fun <- covariance(sill = 1, range = 1, smooth = 1,
                      cov.mod = "powexp", plot = FALSE)
phi <- pi / 4
r <- sqrt(0.5)
A <- matrix(c(cos(phi), r^2 * sin(phi), r^2 * sin(phi), cos(phi)), 2)
cov.fun.aniso <- function(vec.pos)
  cov.fun(sqrt(vec.pos %*% A %*% vec.pos))

rho1 <- rho2 <- matrix(NA, 100, 100)
xs <- ys <- seq(-4, 4, length = 100)
for (i in 1:100){
  x <- xs[i]
  for (j in 1:100){
    rho1[i,j] <- cov.fun(sqrt(x^2+ys[j]^2))
    rho2[i,j] <- cov.fun.aniso(c(x, ys[j]))
  }
}

par(mfrow=c(1,2))
contour(xs, ys, rho1, xlab = expression(paste(Delta, x)),
        ylab = expression(paste(Delta, y)))
contour(xs, ys, rho2, xlab = expression(paste(Delta, x)),
        ylab = expression(paste(Delta, y)))


###################################################
### chunk number 13: extCoeffModels
###################################################
smith <- function(h) 2 * pnorm(h/2)
cov.fun <- covariance(sill = 1, range = 1, smooth = 1, plot = FALSE)
schlather <- function(h)
  1 + sqrt((1-cov.fun(h))/2)
alpha <- 0.1

plot(smith, from = 0, to = 5, xlab = "h", ylab = expression(theta(h)))
plot(schlather, add = TRUE, col = 2, from = 0, to = 5)
legend("bottomright", c("Smith", "Schlather"), col = 1:2, lty = 1, inset = 0.05)


###################################################
### chunk number 14: 
###################################################
smith <- function(h) 2 * pnorm(h/2)
cov.fun <- covariance(sill = 1, range = 1, smooth = 1, plot = FALSE)
schlather <- function(h)
  1 + sqrt((1-cov.fun(h))/2)
alpha <- 0.1

plot(smith, from = 0, to = 5, xlab = "h", ylab = expression(theta(h)))
plot(schlather, add = TRUE, col = 2, from = 0, to = 5)
legend("bottomright", c("Smith", "Schlather"), col = 1:2, lty = 1, inset = 0.05)


###################################################
### chunk number 15: extCoeffST-Smith
###################################################
n.site <- 40
n.obs <- 100
x <- runif(n.site, 0, 10)
y <- runif(n.site, 0, 10)
set.seed(12)
ms0 <- MaxStableRF(x, y, grid=FALSE, model="wh", param=c(0,1,0,1, 1),
                   maxstable="extr", n = n.obs)
ms0 <- t(ms0)
cov.fun <- covariance(sill = 1, range = 1, smooth = 1, cov.mod = "whitmat",
                      plot = FALSE)
ext.coeff <- function(h)
  1 + sqrt((1 - cov.fun(h))/2)

par(mfrow=c(1,2))
ST <- fitextcoeff(ms0, cbind(x, y), loess = FALSE, ylim = c(1, 2))
plot(ext.coeff, from = 0, to = 12, col = 2, add = TRUE, lwd = 1.5)
Smith <- fitextcoeff(ms0, cbind(x, y), estim = "Smith", loess = FALSE, ylim = c(1, 2))
plot(ext.coeff, from = 0, to = 12, col = 2, add = TRUE, lwd = 1.5)


###################################################
### chunk number 16: 
###################################################
n.site <- 40
n.obs <- 100
x <- runif(n.site, 0, 10)
y <- runif(n.site, 0, 10)
set.seed(12)
ms0 <- MaxStableRF(x, y, grid=FALSE, model="wh", param=c(0,1,0,1, 1),
                   maxstable="extr", n = n.obs)
ms0 <- t(ms0)
cov.fun <- covariance(sill = 1, range = 1, smooth = 1, cov.mod = "whitmat",
                      plot = FALSE)
ext.coeff <- function(h)
  1 + sqrt((1 - cov.fun(h))/2)

par(mfrow=c(1,2))
ST <- fitextcoeff(ms0, cbind(x, y), loess = FALSE, ylim = c(1, 2))
plot(ext.coeff, from = 0, to = 12, col = 2, add = TRUE, lwd = 1.5)
Smith <- fitextcoeff(ms0, cbind(x, y), estim = "Smith", loess = FALSE, ylim = c(1, 2))
plot(ext.coeff, from = 0, to = 12, col = 2, add = TRUE, lwd = 1.5)


###################################################
### chunk number 17:  eval=FALSE
###################################################
## n.site <- 40
## n.obs <- 100
## x <- runif(n.site, 0, 10)
## y <- runif(n.site, 0, 10)
## set.seed(12)
## ms0 <- MaxStableRF(x, y, grid=FALSE, model="wh", param=c(0,1,0,1, 1),
##                    maxstable="extr", n = n.obs)
## ms0 <- t(ms0)
## par(mfrow=c(1,2))
## fitextcoeff(ms0, cbind(x, y), loess = FALSE)
## fitextcoeff(ms0, cbind(x, y), estim = "Smith", loess = FALSE)


###################################################
### chunk number 18: madogram
###################################################
cov.fun1 <- covariance(sill = 1, range = 1, smooth = 1,
                       cov.mod = "whitmat", plot = FALSE)
ext.coeff1 <- function(h)
  1 + sqrt((1 - cov.fun1(h))/2)
mado1 <- function(h)
  log(ext.coeff1(h))

cov.fun2 <- covariance(sill = 1, range = 1.5, smooth = 1,
                       cov.mod = "powexp", plot = FALSE)
ext.coeff2 <- function(h)
  1 + sqrt((1 - cov.fun2(h))/2)
mado2 <- function(h)
  log(ext.coeff2(h))

n.site <- 40
n.obs <- 100
x <- runif(n.site, 0, 10)
y <- runif(n.site, 0, 10)
set.seed(12)
ms0 <- MaxStableRF(x, y, grid=FALSE, model="wh", param=c(0,1,0,1, 1),
                   maxstable="extr", n = n.obs)
ms0 <- t(ms0)

par(mfrow=c(1,2))
madogram(ms0, cbind(x, y), which = "mado", ylim = c(0, log(2)))
plot(mado1, from = 0, to = 12, add = TRUE, col = 2, lwd = 1.5)
madogram(ms0, cbind(x, y), which = "mado", ylim = c(0, log(2)),
         n.bins = 100, xlim = c(0, 12))
plot(mado1, from = 0, to = 12, add = TRUE, col = 2, lwd = 1.5)


###################################################
### chunk number 19: 
###################################################
cov.fun1 <- covariance(sill = 1, range = 1, smooth = 1,
                       cov.mod = "whitmat", plot = FALSE)
ext.coeff1 <- function(h)
  1 + sqrt((1 - cov.fun1(h))/2)
mado1 <- function(h)
  log(ext.coeff1(h))

cov.fun2 <- covariance(sill = 1, range = 1.5, smooth = 1,
                       cov.mod = "powexp", plot = FALSE)
ext.coeff2 <- function(h)
  1 + sqrt((1 - cov.fun2(h))/2)
mado2 <- function(h)
  log(ext.coeff2(h))

n.site <- 40
n.obs <- 100
x <- runif(n.site, 0, 10)
y <- runif(n.site, 0, 10)
set.seed(12)
ms0 <- MaxStableRF(x, y, grid=FALSE, model="wh", param=c(0,1,0,1, 1),
                   maxstable="extr", n = n.obs)
ms0 <- t(ms0)

par(mfrow=c(1,2))
madogram(ms0, cbind(x, y), which = "mado", ylim = c(0, log(2)))
plot(mado1, from = 0, to = 12, add = TRUE, col = 2, lwd = 1.5)
madogram(ms0, cbind(x, y), which = "mado", ylim = c(0, log(2)),
         n.bins = 100, xlim = c(0, 12))
plot(mado1, from = 0, to = 12, add = TRUE, col = 2, lwd = 1.5)


###################################################
### chunk number 20:  eval=FALSE
###################################################
## n.site <- 50
## n.obs <- 100
## x <- runif(n.site, 0, 10)
## y <- runif(n.site, 0, 10)
## set.seed(12)
## ms0 <- MaxStableRF(x, y, grid=FALSE, model="wh", param=c(0,1,0,1, 1),
##                    maxstable="extr", n = n.obs)
## ms0 <- t(ms0)
## 
## par(mfrow=c(1,2))
## madogram(ms0, cbind(x, y), which = "mado")
## madogram(ms0, cbind(x, y), which = "mado", n.bins = 100)


###################################################
### chunk number 21: madogramExtCoeff
###################################################
n.site <- 40
n.obs <- 100
x <- runif(n.site, 0, 10)
y <- runif(n.site, 0, 10)
set.seed(12)
ms0 <- MaxStableRF(x, y, grid=FALSE, model="wh", param=c(0,1,0,1, 1),
                   maxstable="extr", n = n.obs)
ms0 <- t(ms0)

cov.fun <- covariance(sill = 1, range = 1, smooth = 1, cov.mod = "whitmat",
                      plot = FALSE)
ext.coeff <- function(h)
  1 + sqrt((1 - cov.fun(h))/2)
mado <- function(h)
  log(ext.coeff(h))

par(mfrow=c(1,2))
madogram(ms0, cbind(x, y), which = "mado", ylim = c(0, log(2)))
plot(mado, from = 0, to = 12, col = 2, lwd = 1.5, add = TRUE)
madogram(ms0, cbind(x, y), which = "ext", ylim = c(1, 2))
plot(ext.coeff, from = 0, to = 12, col = 2, lwd = 1.5, add = TRUE)


###################################################
### chunk number 22: 
###################################################
n.site <- 40
n.obs <- 100
x <- runif(n.site, 0, 10)
y <- runif(n.site, 0, 10)
set.seed(12)
ms0 <- MaxStableRF(x, y, grid=FALSE, model="wh", param=c(0,1,0,1, 1),
                   maxstable="extr", n = n.obs)
ms0 <- t(ms0)

cov.fun <- covariance(sill = 1, range = 1, smooth = 1, cov.mod = "whitmat",
                      plot = FALSE)
ext.coeff <- function(h)
  1 + sqrt((1 - cov.fun(h))/2)
mado <- function(h)
  log(ext.coeff(h))

par(mfrow=c(1,2))
madogram(ms0, cbind(x, y), which = "mado", ylim = c(0, log(2)))
plot(mado, from = 0, to = 12, col = 2, lwd = 1.5, add = TRUE)
madogram(ms0, cbind(x, y), which = "ext", ylim = c(1, 2))
plot(ext.coeff, from = 0, to = 12, col = 2, lwd = 1.5, add = TRUE)


###################################################
### chunk number 23:  eval=FALSE
###################################################
## n.site <- 40
## n.obs <- 100
## x <- runif(n.site, 0, 10)
## y <- runif(n.site, 0, 10)
## set.seed(12)
## ms0 <- MaxStableRF(x, y, grid=FALSE, model="wh", param=c(0,1,0,1, 1),
##                    maxstable="extr", n = n.obs)
## ms0 <- t(ms0)
## madogram(ms0, cbind(x, y))


###################################################
### chunk number 24: F-madogram
###################################################
n.site <- 40
n.obs <- 100
x <- runif(n.site, 0, 10)
y <- runif(n.site, 0, 10)
set.seed(12)
sigma <- matrix(c(1, 0, 0, 1),ncol = 2)
sigma.inv <- solve(sigma)
sqrtCinv <- t(chol(sigma.inv))
model <- list(list(model = "gauss", var = 1, aniso = sqrtCinv / 2))
set.seed(12)
ms0 <- MaxStableRF(x, y, grid = FALSE, model = model, maxstable = "Bool",
                   n = n.obs)
ms0 <- t(ms0)

ext.coeff <- function(h)
  2 * pnorm(h/2)
Fmado <- function(h)
  0.5 * (ext.coeff(h) - 1) / (ext.coeff(h) + 1)

par(mfrow=c(1,2))
fmadogram(ms0, cbind(x, y), which = "mado", ylim = c(0, 1/5))
plot(Fmado, from = 0, to = 13, add = TRUE, col = 2, lwd = 1.5)
fmadogram(ms0, cbind(x, y), which = "ext", ylim = c(1, 2.4))
plot(ext.coeff, from = 0, to = 13, add = TRUE, col = 2, lwd = 1.5)


###################################################
### chunk number 25: 
###################################################
n.site <- 40
n.obs <- 100
x <- runif(n.site, 0, 10)
y <- runif(n.site, 0, 10)
set.seed(12)
sigma <- matrix(c(1, 0, 0, 1),ncol = 2)
sigma.inv <- solve(sigma)
sqrtCinv <- t(chol(sigma.inv))
model <- list(list(model = "gauss", var = 1, aniso = sqrtCinv / 2))
set.seed(12)
ms0 <- MaxStableRF(x, y, grid = FALSE, model = model, maxstable = "Bool",
                   n = n.obs)
ms0 <- t(ms0)

ext.coeff <- function(h)
  2 * pnorm(h/2)
Fmado <- function(h)
  0.5 * (ext.coeff(h) - 1) / (ext.coeff(h) + 1)

par(mfrow=c(1,2))
fmadogram(ms0, cbind(x, y), which = "mado", ylim = c(0, 1/5))
plot(Fmado, from = 0, to = 13, add = TRUE, col = 2, lwd = 1.5)
fmadogram(ms0, cbind(x, y), which = "ext", ylim = c(1, 2.4))
plot(ext.coeff, from = 0, to = 13, add = TRUE, col = 2, lwd = 1.5)


###################################################
### chunk number 26:  eval=FALSE
###################################################
## n.site <- 40
## n.obs <- 100
## x <- runif(n.site, 0, 10)
## y <- runif(n.site, 0, 10)
## set.seed(12)
## sigma <- matrix(c(1, 0, 0, 1),ncol = 2)
## sigma.inv <- solve(sigma)
## sqrtCinv <- t(chol(sigma.inv))
## model <- list(list(model = "gauss", var = 1, aniso = sqrtCinv / 2))
## set.seed(12)
## ms0 <- MaxStableRF(x, y, grid = FALSE, model = model, maxstable = "Bool",
##                    n = n.obs)
## ms0 <- t(ms0)
## 
## par(mfrow=c(1,2))
## fmadogram(ms0, cbind(x, y))


###################################################
### chunk number 27: lambda-madogram
###################################################
n.site <- 40
n.obs <- 100
x <- runif(n.site, 0, 10)
y <- runif(n.site, 0, 10)
set.seed(12)
ms0 <- MaxStableRF(x, y, grid=FALSE, model="stable", param=c(0,1,0,1, 1),
                   maxstable="extr", n = n.obs)
ms0 <- t(ms0)
set.seed(12)
ms1 <- MaxStableRF(x, y, grid=FALSE, model="cauchy", param=c(0,1,0,1, 1),
                   maxstable="extr", n = n.obs)
ms1 <- t(ms1)

par(mfrow=c(1,2), pty = "s")
lmadogram(ms0, cbind(x, y), n.bins = 60)
lmadogram(ms1, cbind(x, y), n.bins = 60)


###################################################
### chunk number 28: 
###################################################
n.site <- 40
n.obs <- 100
x <- runif(n.site, 0, 10)
y <- runif(n.site, 0, 10)
set.seed(12)
ms0 <- MaxStableRF(x, y, grid=FALSE, model="stable", param=c(0,1,0,1, 1),
                   maxstable="extr", n = n.obs)
ms0 <- t(ms0)
set.seed(12)
ms1 <- MaxStableRF(x, y, grid=FALSE, model="cauchy", param=c(0,1,0,1, 1),
                   maxstable="extr", n = n.obs)
ms1 <- t(ms1)

par(mfrow=c(1,2), pty = "s")
lmadogram(ms0, cbind(x, y), n.bins = 60)
lmadogram(ms1, cbind(x, y), n.bins = 60)


###################################################
### chunk number 29:  eval=FALSE
###################################################
## n.site <- 40
## n.obs <- 100
## x <- runif(n.site, 0, 10)
## y <- runif(n.site, 0, 10)
## set.seed(12)
## ms0 <- MaxStableRF(x, y, grid=FALSE, model="stable", param=c(0,1,0,1, 1),
##                    maxstable="extr", n = n.obs)
## ms0 <- t(ms0)
## set.seed(12)
## ms1 <- MaxStableRF(x, y, grid=FALSE, model="cauchy", param=c(0,1,0,1, 1),
##                    maxstable="extr", n = n.obs)
## ms1 <- t(ms1)
## 
## par(mfrow=c(1,2))
## lmadogram(ms0, cbind(x, y), n.bins = 60)
## lmadogram(ms1, cbind(x, y), n.bins = 60)


###################################################
### chunk number 30: 
###################################################
n.site <- 40
n.obs <- 80
locations <- matrix(runif(2*n.site, 0, 10), ncol = 2)
colnames(locations) <- c("lon", "lat")
sigma <- matrix(c(9/8, 1, 1, 9/8),ncol = 2)
sigma.inv <- solve(sigma)
sqrtCinv <- t(chol(sigma.inv))
model <- list(list(model = "gauss", var = 1, aniso = sqrtCinv / 2))
set.seed(12)
ms0 <- MaxStableRF(locations[,1], locations[,2], grid=FALSE, model = model,
                   maxstable = "Bool", n = n.obs)
ms0 <- t(ms0)
fitcovmat(ms0, locations, marge = "emp")


###################################################
### chunk number 31: 
###################################################
n.site <- 40
set.seed(12)
locations <- matrix(runif(2*n.site, 0, 10), ncol = 2)
colnames(locations) <- c("lon", "lat")

ms0 <- MaxStableRF(locations[,1], locations[,2], grid=FALSE, model="wh",
param = c(0,1, .2,3, 1.2), maxstable="extr", n = 80)
ms0 <- t(ms0)
fitmaxstab(ms0, locations, cov.mod = "whitmat", std.err.type = "none")


###################################################
### chunk number 32:  eval=FALSE
###################################################
## fitmaxstab(ms0, locations, cov.mod = "whitmat", smooth = 1.2,
##            std.err.type = "none")
## fitmaxstab(ms0, locations, cov.mod = "whitmat", sill = 1)
## fitmaxstab(ms0, locations, cov.mod = "whitmat", range = 3)


###################################################
### chunk number 33:  eval=FALSE
###################################################
## fitmaxstab(ms0, locations, cov.mod = "cauchy")
## fitmaxstab(ms0, locations, cov.mod = "powexp")


###################################################
### chunk number 34:  eval=FALSE
###################################################
## fitmaxstab(ms0, locations, cov.mod = "gauss")


###################################################
### chunk number 35:  eval=FALSE
###################################################
## fitmaxstab(ms0, locations, cov.mod = "gauss", cov12 = 0, method = "BFGS")


###################################################
### chunk number 36:  eval=FALSE
###################################################
## fitmaxstab(ms0, locations, cov.mod = "gauss", std.err.type = "score")
## fitmaxstab(ms0, locations, cov.mod = "gauss", std.err.type = "grad")


###################################################
### chunk number 37: 
###################################################
set.seed(1)
n.site <- 40
locations <- matrix(runif(2*n.site, 0, 10), ncol = 2)
colnames(locations) <- c("lon", "lat")
ms0 <- MaxStableRF(locations[,1], locations[,2], grid=FALSE, model="cauchy",
                   param=c(0,1,0.2,3, 1.2), maxstable="extr", n = 80)
ms0 <- t(ms0)
model1 <- fitmaxstab(ms0, locations, cov.mod = "powexp")
model2 <- fitmaxstab(ms0, locations, cov.mod = "cauchy")
TIC(model1, model2)


###################################################
### chunk number 38: 
###################################################
set.seed(7)
n.site <- 30
locations <- matrix(rnorm(2*n.site, sd = sqrt(.2)), ncol = 2)
colnames(locations) <- c("lon", "lat")
sigma <- matrix(c(100, 25, 25, 220),ncol = 2)
sigma.inv <- solve(sigma)
sqrtCinv <- t(chol(sigma.inv))
model <- list(list(model = "gauss", var = 1, aniso = sqrtCinv / 2))
ms0 <- MaxStableRF(locations[,1], locations[,2], grid=FALSE, model=model,
                   maxstable = "Bool", n = 50)
ms0 <- t(ms0)

M0 <- fitmaxstab(ms0, locations, "gauss", , cov11 = 100)
M1 <- fitmaxstab(ms0, locations, "gauss")
anova(M0, M1)


###################################################
### chunk number 39: 
###################################################
anova(M0, M1, method = "CB")


###################################################
### chunk number 40: 
###################################################
x <- c(2.2975896, 1.6448808, 1.3323833, -0.4464904, 2.2737603, -0.2581876,
       9.5184398, -0.5899699, 0.4974283, -0.8152157)
z <- gev2frech(x, 1, 2, .2)


###################################################
### chunk number 41: 
###################################################
frech2gev(z, 1, 2, .2)


###################################################
### chunk number 42:  eval=FALSE
###################################################
## fitmaxstab(data, coord, "gauss", fit.marge = TRUE)


###################################################
### chunk number 43: knotsEffect
###################################################
set.seed(12)
x <- runif(100)
fun <- function(x) sin(3 * pi * x)
y <- fun(x) + rnorm(100, 0, 0.15)
knots1 <- quantile(x, prob = 1:2 / 3)
knots2 <- quantile(x, prob = 1:10 / 11)
knots3 <- quantile(x, prob = 1:50 / 51)
M0 <- rbpspline(y, x, knots = knots1, degree = 3, penalty = 0)
M1 <- rbpspline(y, x, knots = knots2, degree = 3, penalty = 0)
M2 <- rbpspline(y, x, knots = knots3, degree = 3, penalty = 0)

par(mfrow=c(1,3))
plot(x, y, col = "lightgrey")
rug(knots1)
lines(M0)
plot(x, y, col = "lightgrey")
rug(knots2)
lines(M1, col = 2)
plot(x, y, col = "lightgrey")
rug(knots3)
lines(M2, col = 3)


###################################################
### chunk number 44: 
###################################################
set.seed(12)
x <- runif(100)
fun <- function(x) sin(3 * pi * x)
y <- fun(x) + rnorm(100, 0, 0.15)
knots1 <- quantile(x, prob = 1:2 / 3)
knots2 <- quantile(x, prob = 1:10 / 11)
knots3 <- quantile(x, prob = 1:50 / 51)
M0 <- rbpspline(y, x, knots = knots1, degree = 3, penalty = 0)
M1 <- rbpspline(y, x, knots = knots2, degree = 3, penalty = 0)
M2 <- rbpspline(y, x, knots = knots3, degree = 3, penalty = 0)

par(mfrow=c(1,3))
plot(x, y, col = "lightgrey")
rug(knots1)
lines(M0)
plot(x, y, col = "lightgrey")
rug(knots2)
lines(M1, col = 2)
plot(x, y, col = "lightgrey")
rug(knots3)
lines(M2, col = 3)


###################################################
### chunk number 45:  eval=FALSE
###################################################
## set.seed(12)
## x <- runif(100)
## fun <- function(x) sin(3 * pi * x)
## y <- fun(x) + rnorm(100, 0, 0.15)
## knots1 <- quantile(x, prob = 1:2 / 3)
## knots2 <- quantile(x, prob = 1:10 / 11)
## knots3 <- quantile(x, prob = 1:50 / 51)
## M0 <- rbpspline(y, x, knots = knots1, degree = 3, penalty = 0)
## M1 <- rbpspline(y, x, knots = knots2, degree = 3, penalty = 0)
## M2 <- rbpspline(y, x, knots = knots3, degree = 3, penalty = 0)
## 
## par(mfrow=c(1,3))
## plot(x, y, col = "lightgrey")
## rug(knots1)
## lines(M0)
## plot(x, y, col = "lightgrey")
## rug(knots2)
## lines(M1, col = 2)
## plot(x, y, col = "lightgrey")
## rug(knots3)
## lines(M2, col = 3)


###################################################
### chunk number 46: smoothingParamEffect
###################################################
M0 <- rbpspline(y, x, knots = knots3, degree = 3, penalty = 0)
M1 <- rbpspline(y, x, knots = knots3, degree = 3, penalty = 0.1)
M2 <- rbpspline(y, x, knots = knots3, degree = 3, penalty = 10)

par(mfrow=c(1,3))
plot(x, y, col = "lightgrey")
lines(M0)
plot(x, y, col = "lightgrey")
lines(M1, col = 2)
plot(x, y, col = "lightgrey")
lines(M2, col = 3)


###################################################
### chunk number 47: 
###################################################
M0 <- rbpspline(y, x, knots = knots3, degree = 3, penalty = 0)
M1 <- rbpspline(y, x, knots = knots3, degree = 3, penalty = 0.1)
M2 <- rbpspline(y, x, knots = knots3, degree = 3, penalty = 10)

par(mfrow=c(1,3))
plot(x, y, col = "lightgrey")
lines(M0)
plot(x, y, col = "lightgrey")
lines(M1, col = 2)
plot(x, y, col = "lightgrey")
lines(M2, col = 3)


###################################################
### chunk number 48:  eval=FALSE
###################################################
## M0 <- rbpspline(y, x, knots = knots3, degree = 3, penalty = 0)
## M1 <- rbpspline(y, x, knots = knots3, degree = 3, penalty = 0.1)
## M2 <- rbpspline(y, x, knots = knots3, degree = 3, penalty = 10)
## 
## par(mfrow=c(1,3))
## plot(x, y, col = "lightgrey")
## lines(M0)
## plot(x, y, col = "lightgrey")
## lines(M1, col = 2)
## plot(x, y, col = "lightgrey")
## lines(M2, col = 3)


###################################################
### chunk number 49: CVandGCV
###################################################
par(mfrow=c(1,3))
lambda.cv <- cv(y, x, knots = knots3, degree = 3)$penalty
abline(v = lambda.cv, lty = 2)
lambda.gcv <- gcv(y, x, knots = knots3, degree = 3)$penalty
abline(v = lambda.gcv, lty = 2)
cv.fit <- rbpspline(y, x, knots3, degree = 3, penalty = "cv")
gcv.fit <- rbpspline(y, x, knots3, degree = 3, penalty = "gcv")
plot(x, y, col = "lightgrey")
lines(cv.fit, col = 2)
lines(gcv.fit, col = 3)


###################################################
### chunk number 50: 
###################################################
par(mfrow=c(1,3))
lambda.cv <- cv(y, x, knots = knots3, degree = 3)$penalty
abline(v = lambda.cv, lty = 2)
lambda.gcv <- gcv(y, x, knots = knots3, degree = 3)$penalty
abline(v = lambda.gcv, lty = 2)
cv.fit <- rbpspline(y, x, knots3, degree = 3, penalty = "cv")
gcv.fit <- rbpspline(y, x, knots3, degree = 3, penalty = "gcv")
plot(x, y, col = "lightgrey")
lines(cv.fit, col = 2)
lines(gcv.fit, col = 3)


###################################################
### chunk number 51:  eval=FALSE
###################################################
## par(mfrow=c(1,3))
## lambda.cv <- cv(y, x, knots = knots3, degree = 3)$penalty
## abline(v = lambda.cv, lty = 2)
## lambda.gcv <- gcv(y, x, knots = knots3, degree = 3)$penalty
## abline(v = lambda.gcv, lty = 2)
## cv.fit <- rbpspline(y, x, knots3, degree = 3, penalty = "cv")
## gcv.fit <- rbpspline(y, x, knots3, degree = 3, penalty = "gcv")
## plot(x, y, col = "lightgrey")
## lines(cv.fit, col = 2)
## lines(gcv.fit, col = 3)


###################################################
### chunk number 52: 
###################################################
n.site <- 20
set.seed(15)
locations <- matrix(runif(2*n.site, 0, 10), ncol = 2)
colnames(locations) <- c("lon", "lat")

sigma <- matrix(c(100, 25, 25, 220),ncol = 2)
sigma.inv <- solve(sigma)
sqrtCinv <- t(chol(sigma.inv))
model <- list(list(model = "gauss", var = 1, aniso = sqrtCinv/2))
ms0 <- MaxStableRF(locations[,1], locations[,2], grid = FALSE, model = model,
                   maxstable="Bool", n = 50)
ms1 <- t(ms0)

param.loc <- -10 + 2 * locations[,2]
param.scale <- 5 + 2 * locations[,1] + locations[,2]^2
param.shape <- rep(0.2, n.site)

for (i in 1:n.site)
  ms1[,i] <- frech2gev(ms1[,i], param.loc[i], param.scale[i], param.shape[i])


###################################################
### chunk number 53: 
###################################################
loc.form <- y ~ lat
scale.form <- y ~ lon + I(lat^2)
shape.form <- y ~ 1
shape.form2 <- y ~ lon
M1 <- fitspatgev(ms1, locations, loc.form, scale.form, shape.form)
M2 <- fitspatgev(ms1, locations, loc.form, scale.form, shape.form2)
M1


###################################################
### chunk number 54: 
###################################################
anova(M1, M2)
TIC(M1, M2)


